%% latextableI.m
%
% Creates LaTeX tables of equilibrium thresholds (Table I in Abbring and Campbell's ``Last-In First-Out Oligopoly Dynamics''). 
%
% At its conclusion, the string tablestra has the table of entry thresholds, while tablestrb has the analogous table of exit thresholds.

%% Acquire thresholds and transform them.
% If the variables |entryThresholds| and |exitThresholds| do not exist, run |experimentI.m| to create them. With the
% thresholds in hand, transform them into levels for reporting. 

newrun=~(exist('entryThresholds','var') && exist('exitThresholds','var'));
if newrun;
    newrunHOLD=1;
    experimentI;
end

entryThresholds=exp(entryThresholds);
exitThresholds=exp(exitThresholds);

%% Create the LaTeX table
% The LaTeX table's first panel reports the entry thresholds and its second panel reports the exit thresholds. We place
% these into separate |tabular| environments.

% Create strings with LaTeX tabular overhead
headerstr1 = ['\begin{tabular}{*{' num2str(size(entryThresholds,2)+1) '}{c}}'];

%Econometrica requires tables to begin with a double rule. This inserts one if doublerule=='Yes'.
if strcmp(doublerule,'Yes')    
    headerstr1doublerule='\hline\hline\\';
else
    headerstr1doublerule=' ';
end
headerstrCase=['\multicolumn{' num2str(size(entryThresholds,2)+1) '}{c}{' descstr '}\\ \\'];    %This places a row in the tabular describing the specification.
headerstr2a = [' & \multicolumn{' num2str(size(entryThresholds,2)) '}{c}{Entry Thresholds} \\'];
headerstr2b = [' & \multicolumn{' num2str(size(exitThresholds,2)) '}{c}{Exit Thresholds} \\'];
headerstr3a = ['$\sigma $' num2str(1:1:size(entryThresholds,2),' & $\\overline{C}_{%1.0f}$') ' \\ \hline'];
headerstr3b = ['$\sigma $' num2str(1:1:size(entryThresholds,2),' & $\\underline{C}_{%1.0f}$') ' \\ \hline'];
closestr = '\end{tabular}';

% Contents
contentstra = ' ';
contentstrb = ' ';
for iter=1:size(entryThresholds,1);
    
    addThis= num2str(sigmaG(iter),'%2.2f ');
        for jiter=1:size(entryThresholds,2)
            if ~isnan(entryThresholds(iter,jiter))
                addThis = [addThis num2str(entryThresholds(iter,jiter),'& \\makebox[24pt]{%2.2f}')];
            else
                addThis = [addThis ' & \makebox[24pt]{ }'];
            end
        end
        addThis = [addThis '\\ '];
        contentstra = strvcat(contentstra,addThis);
        
    addThis = num2str(sigmaG(iter),'%2.2f ');
        for jiter=1:size(exitThresholds,2)
            if ~isnan(exitThresholds(iter,jiter))
                addThis = [addThis num2str(exitThresholds(iter,jiter),'& \\makebox[24pt]{%2.2f}')];
            else
                addThis = [addThis ' & \makebox[24pt]{ }'];
            end
        end
        addThis = [addThis '\\ '];
        contentstrb = strvcat(contentstrb,addThis);
        
end
   
%% Assemble the final output.
tablestra=strvcat(headerstr1,headerstr1doublerule,headerstrCase,headerstr2a,headerstr3a,contentstra,closestr);
tablestrb=strvcat(headerstr1,headerstr2b,headerstr3b,contentstrb,closestr);

%% Report output if this is a test run.
if exist('newrunHOLD','var')
    disp(entryThresholds);
    disp(tablestra);
    
    disp(exitThresholds);
    disp(tablestrb);
    clear newrunHOLD
end
