%% latextableII.m
%
% Creates LaTeX tables of probit thresholds (Table II in Abbring and Campbell's ``Last-In First-Out Oligopoly Dynamics''). 
%
% At its conclusion, the string tablestra has the table of estimated thresholds, while tablestrb has the table of implied profits per consumer.

%% Acquire thresholds and transform them.
% If |probitThresholds| or |PiRatio| do not exist, run |experimentII.m| to create them.

newrun=~(exist('probitThresholds','var') && exist('PiRatio','var'));
if newrun;
    newrunHOLD=1;   
    experimentII;
end

%% Create the LaTeX table
% The LaTeX table's first panel reports the estimated probit thresholds, and its second panel reports the implied ratios
% of producer's surplus per consumeer. We place these into separate |tabular| environments.

% Create strings with LaTeX tabular overhead
headerstr1 = ['\begin{tabular}{*{' num2str(size(probitThresholds,2)+1) '}{c}}'];
headerstrDoubleRule='\hline\hline\\';   %This is the double rule required by Econometrica.
headerstr2a = [' & \multicolumn{' num2str(size(probitThresholds,2)) '}{c}{Implied Static Entry Thresholds} \\'];
headerstr2b = [' & \multicolumn{' num2str(size(probitThresholds,2)) '}{c}{Implied $\pi(N)/\pi(1)$ for $N=$} \\'];
headerstr3a = ['$\sigma $' num2str(1:1:size(probitThresholds,2),' & $C^{\\star}_{%1.0f}$') ' \\ \hline'];
headerstr3b=  ['$\sigma $' num2str(1:1:size(probitThresholds,2),' & %1.0f') ' \\ \hline'];
closestr = '\end{tabular}';

% Contents
contentstra = ' ';
contentstrb = ' ';
for iter=1:nPoints;
    
    addThis= num2str(sigmaG(iter),'%2.2f ');
        for jiter=1:size(probitThresholds,2)
            if ~isnan(probitThresholds(iter,jiter))
                addThis = [addThis num2str(probitThresholds(iter,jiter),'& \\makebox[24pt]{%2.2f}')];
            else
                addThis = [addThis ' & \makebox[24pt]{ }'];
            end
        end
        addThis = [addThis '\\ '];
        contentstra = strvcat(contentstra,addThis);
        
    addThis = num2str(sigmaG(iter),'%2.2f ');
        for jiter=1:size(PiRatio,2)
            if ~isnan(PiRatio(iter,jiter))
                addThis = [addThis num2str(PiRatio(iter,jiter),'& \\makebox[24pt]{%2.2f}')];
            else
                addThis = [addThis ' & \makebox[24pt]{ }'];
            end
        end
        addThis = [addThis '\\ '];
        contentstrb = strvcat(contentstrb,addThis);
        
end
   
%% Assemble the final output.
tablestra=strvcat(headerstr1,headerstrDoubleRule,headerstr2a,headerstr3a,contentstra,closestr);
tablestrb=strvcat(headerstr1,headerstr2b,headerstr3b,contentstrb,closestr);

%% Display output if this is a test run.
if exist('newrunHOLD','var')
    disp(probitThresholds);
    disp(tablestra);
    disp(PiRatio);
    disp(tablestrb);
    clear newrunHOLD
end
